@@ -3,11 +3,13 @@ use console::{strip_ansi_codes, style, user_attended};
 use indicatif::ProgressBar;
 use reqwest::{Client, Response, StatusCode, Url};
 #[cfg(not(target_os = "windows"))]
-use rlimit::{getrlimit, setrlimit, Resource, Rlim};
+use rlimit::{getrlimit, setrlimit, Resource};
 use std::{
     fs,
     io::{self, BufWriter, Write},
     sync::Arc,
+    time::Duration,
+    time::{SystemTime, UNIX_EPOCH},
 };
 use tokio::sync::mpsc::UnboundedSender;
 
@@ -217,16 +219,15 @@ pub fn create_report_string(
 /// as the adjustment made here is only valid for the scan itself (and any child processes, of which
 /// there are none).
 #[cfg(not(target_os = "windows"))]
-pub fn set_open_file_limit(limit: usize) -> bool {
+pub fn set_open_file_limit(limit: u64) -> bool {
     log::trace!("enter: set_open_file_limit");
 
     if let Ok((soft, hard)) = getrlimit(Resource::NOFILE) {
-        if hard.as_usize() > limit {
+        if hard > limit {
             // our default open file limit is less than the current hard limit, this means we can
             // set the soft limit to our default
-            let new_soft_limit = Rlim::from_usize(limit);
 
-            if setrlimit(Resource::NOFILE, new_soft_limit, hard).is_ok() {
+            if setrlimit(Resource::NOFILE, limit, hard).is_ok() {
                 log::debug!("set open file descriptor limit to {}", limit);
 
                 log::trace!("exit: set_open_file_limit -> {}", true);
@@ -298,7 +299,7 @@ pub fn should_deny_url(url: &Url, handles: Arc<Handles>) -> Result<bool> {
     );
     // normalization for comparison is to remove the trailing / if one exists, this is done for
     // the given url and any url to which it's compared
-    let normed_url = Url::parse(&url.to_string().trim_end_matches('/'))?;
+    let normed_url = Url::parse(url.to_string().trim_end_matches('/'))?;
 
     for deny_url in &handles.config.url_denylist {
         // parse the denying url for easier comparison
@@ -385,6 +386,32 @@ pub fn should_deny_url(url: &Url, handles: Arc<Handles>) -> Result<bool> {
     Ok(false)
 }
 
+/// given a url and filename-suffix, return a unique filename comprised of the slugified url,
+/// current unix timestamp and suffix
+///
+/// ex: ferox-http_telsa_com-1606947491.state
+pub fn slugify_filename(url: &str, prefix: &str, suffix: &str) -> String {
+    log::trace!("enter: slugify({:?}, {:?}, {:?})", url, prefix, suffix);
+
+    let ts = SystemTime::now()
+        .duration_since(UNIX_EPOCH)
+        .unwrap_or_else(|_| Duration::from_secs(0))
+        .as_secs();
+
+    let altered_prefix = if !prefix.is_empty() {
+        format!("{}-", prefix)
+    } else {
+        String::new()
+    };
+
+    let slug = url.replace("://", "_").replace("/", "_").replace(".", "_");
+
+    let filename = format!("{}{}-{}.{}", altered_prefix, slug, ts, suffix);
+
+    log::trace!("exit: slugify -> {}", filename);
+    filename
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -395,7 +422,7 @@ mod tests {
     /// set_open_file_limit with a low requested limit succeeds
     fn utils_set_open_file_limit_with_low_requested_limit() {
         let (_, hard) = getrlimit(Resource::NOFILE).unwrap();
-        let lower_limit = hard.as_usize() - 1;
+        let lower_limit = hard - 1;
         assert!(set_open_file_limit(lower_limit));
     }
 
@@ -403,9 +430,9 @@ mod tests {
     /// set_open_file_limit with a high requested limit succeeds
     fn utils_set_open_file_limit_with_high_requested_limit() {
         let (_, hard) = getrlimit(Resource::NOFILE).unwrap();
-        let higher_limit = hard.as_usize() + 1;
+        let higher_limit = hard + 1;
         // calculate a new soft to ensure soft != hard and hit that logic branch
-        let new_soft = Rlim::from_usize(hard.as_usize() - 1);
+        let new_soft = hard - 1;
         setrlimit(Resource::NOFILE, new_soft, hard).unwrap();
         assert!(set_open_file_limit(higher_limit));
     }
@@ -416,7 +443,7 @@ mod tests {
         let (_, hard) = getrlimit(Resource::NOFILE).unwrap();
         // calculate a new soft to ensure soft == hard and hit the failure logic branch
         setrlimit(Resource::NOFILE, hard, hard).unwrap();
-        assert!(!set_open_file_limit(hard.as_usize())); // returns false
+        assert!(!set_open_file_limit(hard)); // returns false
     }
 
     #[test]
@@ -476,7 +503,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -495,7 +522,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -514,7 +541,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -535,7 +562,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -556,7 +583,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -575,7 +602,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/api/denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -594,7 +621,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/not-denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -613,7 +640,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/stuff/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
@@ -632,7 +659,7 @@ mod tests {
         let tested_url = Url::parse("https://testdomain.com/api/not-denied/").unwrap();
 
         let scans = Arc::new(FeroxScans::default());
-        scans.add_directory_scan(&scan_url, ScanOrder::Initial);
+        scans.add_directory_scan(scan_url, ScanOrder::Initial);
 
         let mut config = Configuration::new().unwrap();
         config.url_denylist = vec![String::from(deny_url)];
